==> phpnuke-5.5.tgz: www/phpnuke/html/modules/News/language/lang-czech.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please sent to me (fbc@mandrakesoft.com)    */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_SEND","Poslat");
define("_URL","URL");
define("_PRINTER","Vytisknout strnku");
define("_FRIEND","Poslat tento lnek znmm");
define("_YOURNAME","Vae jmno");
define("_OK","Ok!");
define("_RELATED","Pbuzn odkazy");
define("_MOREABOUT","Vce o");
define("_NEWSBY","Novinky od");
define("_MOSTREAD","Nejtenj lnka o");
define("_READMORE","Vce...");
define("_BYTESMORE","byt");
define("_COMMENTSQ","komente?");
define("_COMMENT","koment");
define("_CONFIGURE","Nastaven");
define("_LOGINCREATE","Pihlsit/Vytvoit et");
define("_THRESHOLD","Prhy");
define("_NOCOMMENTS","Bez komente");
define("_NESTED","Vkldan");
define("_FLAT","Patra");
define("_THREAD","Strom");
define("_OLDEST","Nejdve star");
define("_NEWEST","Nejdve novj");
define("_HIGHEST","Nejdve s nejvym skre");
define("_COMMENTSWARNING","Za obsah komente zodpovd jeho autor.");
define("_SCORE","Skre:");
define("_USERINFO","O uivateli");
define("_READREST","Pest zbytek komente...");
define("_REPLY","Odpovdt");
define("_REPLYMAIN","Poslat koment");
define("_NOSUBJECT","Chyb pedmt");
define("_NOANONCOMMENTS","Nen povoleno poslat komente anonymn, prosm <a href=\"modules.php?name=Your_Account\">registrijte se</a>");
define("_PARENT","Nadazen");
define("_ROOT","Hlavn");
define("_UCOMMENT","Koment");
define("_ALLOWEDHTML","Povolit HTML:");
define("_POSTANON","Poslat anonymn");
define("_EXTRANS","Extrans (html tagy do textu)");
define("_HTMLFORMATED","HTML formtovn");
define("_PLAINTEXT","Prost text");
define("_ONN","na...");
define("_SUBJECT","Pedmt");
define("_COMMENTREPLY","Koment");
define("_COMREPLYPRE","Prohldnout koment");
define("_NOTRIGHT","S touto funkc nen nco v podku.");
define("_SENDAMSG","Poslat zprvu");
define("_YOUSENDSTORY","Polete tento lnek");
define("_TOAFRIEND","tmto znmm:");
define("_FYOURNAME","Vae jmno:");
define("_FYOUREMAIL","V e-mail:");
define("_FFRIENDNAME","Adrestovo jmno(v 5.pd):");
define("_FFRIENDEMAIL","Adrestv e-mail:");
define("_INTERESTING","Zajmav lnky na");
define("_HELLO","Ahoj");
define("_YOURFRIEND","V ptel");
define("_CONSIDERED","se domnv, e by vs mohl tento lnek zajmat a rozhodl se vm ho poslat.");
define("_FDATE","Datum:");
define("_FTOPIC","Tma:");
define("_YOUCANREAD","Dal zajmav lnky si mete pest na");
define("_FSTORY","lnek");
define("_HASSENT","byl odesln");
define("_THANKS","Dky!");
define("_RECOMMEND","Doporute tuto strnku znmm");
define("_PDATE","Datum:");
define("_PTOPIC","Tma:");
define("_COMESFROM","Tento lnek najdete na");
define("_THEURL","Adresa tohoto lnku je:");
define("_PREVIEW","Prohldnout");
define("_NEWUSER","Nov uivatel");
define("_OPTIONS","Monosti");
define("_REFRESH","Obnovit");
define("_ADD","Pidat");
define("_NOCOMMENTSACT","Sorry, Comments are not available for this article.");
define("_ARTICLEPOLL","Article's Poll");
define("_RATEARTICLE","Article Rating");
define("_RATETHISARTICLE","Please take a second and vote for this article:");
define("_CASTMYVOTE","Cast my Vote!");
define("_AVERAGESCORE","Average Score");
define("_BAD","Bad");
define("_REGULAR","Regular");
define("_GOOD","Good");
define("_VERYGOOD","Very Good");
define("_EXCELLENT","Excellent");
define("_ARTICLERATING","Article Rating");
define("_THANKSVOTEARTICLE","Thanks for voting for this article!");
define("_ALREADYVOTEDARTICLE","Sorry, you already voted for this article recently!");
define("_BACKTOARTICLEPAGE","Back to Article's Page");
define("_DIDNTRATE","You didn't selected any score for the article!");
define("_NOINFO4TOPIC","Sorry, there isn't information for the selected topic.");
define("_GOTONEWSINDEX","Go to News Index");
define("_SELECTNEWTOPIC","Select a New Topic");
define("_GOTOHOME","Go to Home");
define("_SEARCHONTOPIC","Search on This Topic");

?>

==> phpnuke-5.6.tgz: www/phpnuke/html/modules/News/language/lang-czech.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please go to the site and send to me        */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_SEND","Poslat");
define("_URL","URL");
define("_PRINTER","Vytisknout strnku");
define("_FRIEND","Poslat tento lnek znmm");
define("_YOURNAME","Vae jmno");
define("_OK","Ok!");
define("_RELATED","Pbuzn odkazy");
define("_MOREABOUT","Vce o");
define("_NEWSBY","Novinky od");
define("_MOSTREAD","Nejtenj lnka o");
define("_READMORE","Vce...");
define("_BYTESMORE","byt");
define("_COMMENTSQ","komente?");
define("_COMMENT","koment");
define("_CONFIGURE","Nastaven");
define("_LOGINCREATE","Pihlsit/Vytvoit et");
define("_THRESHOLD","Prhy");
define("_NOCOMMENTS","Bez komente");
define("_NESTED","Vkldan");
define("_FLAT","Patra");
define("_THREAD","Strom");
define("_OLDEST","Nejdve star");
define("_NEWEST","Nejdve novj");
define("_HIGHEST","Nejdve s nejvym skre");
define("_COMMENTSWARNING","Za obsah komente zodpovd jeho autor.");
define("_SCORE","Skre:");
define("_USERINFO","O uivateli");
define("_READREST","Pest zbytek komente...");
define("_REPLY","Odpovdt");
define("_REPLYMAIN","Poslat koment");
define("_NOSUBJECT","Chyb pedmt");
define("_NOANONCOMMENTS","Nen povoleno poslat komente anonymn, prosm <a href=\"modules.php?name=Your_Account\">registrijte se</a>");
define("_PARENT","Nadazen");
define("_ROOT","Hlavn");
define("_UCOMMENT","Koment");
define("_ALLOWEDHTML","Povolit HTML:");
define("_POSTANON","Poslat anonymn");
define("_EXTRANS","Extrans (html tagy do textu)");
define("_HTMLFORMATED","HTML formtovn");
define("_PLAINTEXT","Prost text");
define("_ONN","na...");
define("_SUBJECT","Pedmt");
define("_COMMENTREPLY","Koment");
define("_COMREPLYPRE","Prohldnout koment");
define("_NOTRIGHT","S touto funkc nen nco v podku.");
define("_SENDAMSG","Poslat zprvu");
define("_YOUSENDSTORY","Polete tento lnek");
define("_TOAFRIEND","tmto znmm:");
define("_FYOURNAME","Vae jmno:");
define("_FYOUREMAIL","V e-mail:");
define("_FFRIENDNAME","Adrestovo jmno(v 5.pd):");
define("_FFRIENDEMAIL","Adrestv e-mail:");
define("_INTERESTING","Zajmav lnky na");
define("_HELLO","Ahoj");
define("_YOURFRIEND","V ptel");
define("_CONSIDERED","se domnv, e by vs mohl tento lnek zajmat a rozhodl se vm ho poslat.");
define("_FDATE","Datum:");
define("_FTOPIC","Tma:");
define("_YOUCANREAD","Dal zajmav lnky si mete pest na");
define("_FSTORY","lnek");
define("_HASSENT","byl odesln");
define("_THANKS","Dky!");
define("_RECOMMEND","Doporute tuto strnku znmm");
define("_PDATE","Datum:");
define("_PTOPIC","Tma:");
define("_COMESFROM","Tento lnek najdete na");
define("_THEURL","Adresa tohoto lnku je:");
define("_PREVIEW","Prohldnout");
define("_NEWUSER","Nov uivatel");
define("_OPTIONS","Monosti");
define("_REFRESH","Obnovit");
define("_ADD","Pidat");
define("_NOCOMMENTSACT","Sorry, Comments are not available for this article.");
define("_ARTICLEPOLL","Article's Poll");
define("_RATEARTICLE","Article Rating");
define("_RATETHISARTICLE","Please take a second and vote for this article:");
define("_CASTMYVOTE","Cast my Vote!");
define("_AVERAGESCORE","Average Score");
define("_BAD","Bad");
define("_REGULAR","Regular");
define("_GOOD","Good");
define("_VERYGOOD","Very Good");
define("_EXCELLENT","Excellent");
define("_ARTICLERATING","Article Rating");
define("_THANKSVOTEARTICLE","Thanks for voting for this article!");
define("_ALREADYVOTEDARTICLE","Sorry, you already voted for this article recently!");
define("_BACKTOARTICLEPAGE","Back to Article's Page");
define("_DIDNTRATE","You didn't selected any score for the article!");
define("_NOINFO4TOPIC","Sorry, there isn't information for the selected topic.");
define("_GOTONEWSINDEX","Go to News Index");
define("_SELECTNEWTOPIC","Select a New Topic");
define("_GOTOHOME","Go to Home");
define("_SEARCHONTOPIC","Search on This Topic");

?>
